# Flytekit SQLAlchemy Plugin

SQLAlchemy is the Python SQL toolkit and Object Relational Mapper that gives application developers the full power and flexibility of SQL. Flyte provides an easy-to-use interface to utilize SQLAlchemy to connect to various SQL Databases.

To install the plugin, run the following command:

```bash
pip install flytekitplugins-sqlalchemy
```

An [example](https://docs.flyte.org/projects/cookbook/en/latest/auto/integrations/flytekit_plugins/sql/sql-alchemy.html) can be found in the documentation.
